@@ -95,13 +95,13 @@ class FakeDirectoryUnitTest(TestCase):
         def set_size():
             self.fake_file.size = 0.1
 
-        self.assert_raises_io_error(errno.ENOSPC, set_size)
+        self.assert_raises_os_error(errno.ENOSPC, set_size)
 
     def test_should_throw_if_set_size_is_negative(self):
         def set_size():
             self.fake_file.size = -1
 
-        self.assert_raises_io_error(errno.ENOSPC, set_size)
+        self.assert_raises_os_error(errno.ENOSPC, set_size)
 
     def test_produce_empty_file_if_set_size_is_zero(self):
         self.fake_file.size = 0
@@ -122,11 +122,10 @@ class FakeDirectoryUnitTest(TestCase):
     def test_set_contents_to_dir_raises(self):
         # Regression test for #276
         self.filesystem.is_windows_fs = True
-        error_check = (self.assert_raises_io_error if self.is_python2
-                       else self.assert_raises_os_error)
-        error_check(errno.EISDIR, self.fake_dir.set_contents, 'a')
+        self.assert_raises_os_error(
+            errno.EISDIR, self.fake_dir.set_contents, 'a')
         self.filesystem.is_windows_fs = False
-        self.assert_raises_io_error(
+        self.assert_raises_os_error(
             errno.EISDIR, self.fake_dir.set_contents, 'a')
 
     def test_pads_with_nullbytes_if_size_is_greater_than_current_size(self):
@@ -180,11 +179,11 @@ class SetLargeFileSizeTest(TestCase):
                                                   filesystem=filesystem)
 
     def test_should_throw_if_size_is_not_integer(self):
-        self.assert_raises_io_error(errno.ENOSPC,
+        self.assert_raises_os_error(errno.ENOSPC,
                                     self.fake_file.set_large_file_size, 0.1)
 
     def test_should_throw_if_size_is_negative(self):
-        self.assert_raises_io_error(errno.ENOSPC,
+        self.assert_raises_os_error(errno.ENOSPC,
                                     self.fake_file.set_large_file_size, -1)
 
     def test_sets_content_none_if_size_is_non_negative_integer(self):
@@ -339,17 +338,17 @@ class FakeFilesystemUnitTest(TestCase):
     def test_get_nonexistent_object_from_root_error(self):
         self.filesystem.add_object(self.root_name, self.fake_file)
         self.assertEqual(self.fake_file, self.filesystem.get_object('foobar'))
-        self.assert_raises_io_error(
+        self.assert_raises_os_error(
             errno.ENOENT, self.filesystem.get_object, 'some_bogus_filename')
 
     def test_remove_object_from_root(self):
         self.filesystem.add_object(self.root_name, self.fake_file)
         self.filesystem.remove_object(self.fake_file.name)
-        self.assert_raises_io_error(
+        self.assert_raises_os_error(
             errno.ENOENT, self.filesystem.get_object, self.fake_file.name)
 
     def test_remove_nonexisten_object_from_root_error(self):
-        self.assert_raises_io_error(
+        self.assert_raises_os_error(
             errno.ENOENT, self.filesystem.remove_object, 'some_bogus_filename')
 
     def test_exists_removed_file(self):
@@ -396,7 +395,7 @@ class FakeFilesystemUnitTest(TestCase):
     def test_get_nonexistent_object_from_child_error(self):
         self.filesystem.add_object(self.root_name, self.fake_child)
         self.filesystem.add_object(self.fake_child.name, self.fake_file)
-        self.assert_raises_io_error(errno.ENOENT, self.filesystem.get_object,
+        self.assert_raises_os_error(errno.ENOENT, self.filesystem.get_object,
                                     self.filesystem.joinpaths(
                                         self.fake_child.name,
                                         'some_bogus_filename'))
@@ -407,19 +406,19 @@ class FakeFilesystemUnitTest(TestCase):
         target_path = self.filesystem.joinpaths(self.fake_child.name,
                                                 self.fake_file.name)
         self.filesystem.remove_object(target_path)
-        self.assert_raises_io_error(errno.ENOENT, self.filesystem.get_object,
+        self.assert_raises_os_error(errno.ENOENT, self.filesystem.get_object,
                                     target_path)
 
     def test_remove_object_from_child_error(self):
         self.filesystem.add_object(self.root_name, self.fake_child)
-        self.assert_raises_io_error(
+        self.assert_raises_os_error(
             errno.ENOENT, self.filesystem.remove_object,
             self.filesystem.joinpaths(self.fake_child.name,
                                       'some_bogus_filename'))
 
     def test_remove_object_from_non_directory_error(self):
         self.filesystem.add_object(self.root_name, self.fake_file)
-        self.assert_raises_io_error(
+        self.assert_raises_os_error(
             errno.ENOTDIR, self.filesystem.remove_object,
             self.filesystem.joinpaths(
                 '%s' % self.fake_file.name,
@@ -440,13 +439,13 @@ class FakeFilesystemUnitTest(TestCase):
             self.fake_child.name, self.fake_grandchild.name)
         grandchild_file = self.filesystem.joinpaths(
             grandchild_directory, self.fake_file.name)
-        self.assertRaises(IOError, self.filesystem.get_object, grandchild_file)
+        self.assertRaises(OSError, self.filesystem.get_object, grandchild_file)
         self.filesystem.add_object(grandchild_directory, self.fake_file)
         self.assertEqual(self.fake_file,
                          self.filesystem.get_object(grandchild_file))
         self.assertTrue(self.filesystem.exists(grandchild_file))
         self.filesystem.remove_object(grandchild_file)
-        self.assertRaises(IOError, self.filesystem.get_object, grandchild_file)
+        self.assertRaises(OSError, self.filesystem.get_object, grandchild_file)
         self.assertFalse(self.filesystem.exists(grandchild_file))
 
     def test_create_directory_in_root_directory(self):
@@ -489,14 +488,9 @@ class FakeFilesystemUnitTest(TestCase):
         file_path = dir_path + '/baz'
 
         if not is_root():
-            if sys.version_info[0] < 3:
-                self.assert_raises_io_error(errno.EACCES,
-                                            self.filesystem.create_file,
-                                            file_path)
-            else:
-                self.assert_raises_os_error(errno.EACCES,
-                                            self.filesystem.create_file,
-                                            file_path)
+            self.assert_raises_os_error(errno.EACCES,
+                                        self.filesystem.create_file,
+                                        file_path)
         else:
             self.filesystem.create_file(file_path)
             self.assertTrue(self.filesystem.exists(file_path))
@@ -584,8 +578,6 @@ class FakeFilesystemUnitTest(TestCase):
         self.assert_raises_os_error(
             errno.EEXIST, self.filesystem.create_file, path)
 
-    @unittest.skipIf(TestCase.is_windows and sys.version_info < (3, 3),
-                     'Links are not supported under Windows before Python 3.3')
     def test_create_link(self):
         path = 'foo/bar/baz'
         target_path = 'foo/bar/quux'
@@ -602,8 +594,6 @@ class FakeFilesystemUnitTest(TestCase):
         self.assertTrue(self.filesystem.exists(path))
         self.assertTrue(self.filesystem.exists(target_path))
 
-    @unittest.skipIf(TestCase.is_windows and sys.version_info < (3, 3),
-                     'Links are not supported under Windows before Python 3.3')
     def test_resolve_object(self):
         target_path = 'dir/target'
         target_contents = '0123456789ABCDEF'
@@ -615,8 +605,6 @@ class FakeFilesystemUnitTest(TestCase):
         self.assertEqual('target', obj.name)
         self.assertEqual(target_contents, obj.contents)
 
-    @unittest.skipIf(TestCase.is_windows and sys.version_info < (3, 3),
-                     'Links are not supported under Windows before Python 3.3')
     def check_lresolve_object(self):
         target_path = 'dir/target'
         target_contents = '0123456789ABCDEF'
@@ -628,8 +616,6 @@ class FakeFilesystemUnitTest(TestCase):
         self.assertEqual(link_name, obj.name)
         self.assertEqual(target_path, obj.contents)
 
-    @unittest.skipIf(sys.version_info < (3, 3),
-                     'Links are not supported under Windows before Python 3.3')
     def test_lresolve_object_windows(self):
         self.filesystem.is_windows_fs = True
         self.check_lresolve_object()
@@ -640,9 +626,9 @@ class FakeFilesystemUnitTest(TestCase):
 
     def check_directory_access_on_file(self, error_subtype):
         self.filesystem.create_file('not_a_dir')
-        self.assert_raises_io_error(
+        self.assert_raises_os_error(
             error_subtype, self.filesystem.resolve, 'not_a_dir/foo')
-        self.assert_raises_io_error(
+        self.assert_raises_os_error(
             error_subtype, self.filesystem.lresolve, 'not_a_dir/foo/bar')
 
     def test_directory_access_on_file_windows(self):
@@ -704,8 +690,6 @@ class CaseInsensitiveFakeFilesystemTest(TestCase):
         dir2 = self.filesystem.get_object('/foo/bar')
         self.assertEqual(dir1, dir2)
 
-    @unittest.skipIf(TestCase.is_windows and sys.version_info < (3, 3),
-                     'Links are not supported under Windows before Python 3.3')
     def test_resolve_path(self):
         self.filesystem.create_dir('/foo/baz')
         self.filesystem.create_symlink('/Foo/Bar', './baz/bip')
@@ -754,13 +738,13 @@ class CaseSensitiveFakeFilesystemTest(TestCase):
     def test_get_object(self):
         self.filesystem.create_dir('/foo/bar')
         self.filesystem.create_file('/foo/bar/baz')
-        self.assertRaises(IOError, self.filesystem.get_object, '/Foo/Bar/Baz')
+        self.assertRaises(OSError, self.filesystem.get_object, '/Foo/Bar/Baz')
 
     def test_remove_object(self):
         self.filesystem.create_dir('/foo/bar')
         self.filesystem.create_file('/foo/bar/baz')
         self.assertRaises(
-            IOError, self.filesystem.remove_object, '/Foo/Bar/Baz')
+            OSError, self.filesystem.remove_object, '/Foo/Bar/Baz')
         self.assertTrue(self.filesystem.exists('/foo/bar/baz'))
 
     def test_exists(self):
@@ -955,8 +939,6 @@ class FakePathModuleTest(TestCase):
         self.assertEqual('!george!washington!bridge',
                          self.os.path.realpath('bridge'))
 
-    @unittest.skipIf(TestCase.is_windows and sys.version_info < (3, 2),
-                     'No Windows support before 3.2')
     def test_samefile(self):
         file_path1 = '!foo!bar!baz'
         file_path2 = '!foo!bar!boo'
@@ -973,8 +955,6 @@ class FakePathModuleTest(TestCase):
         self.assertTrue(self.path.exists(file_path))
         self.assertFalse(self.path.exists('!some!other!bogus!path'))
 
-    @unittest.skipIf(TestCase.is_windows and sys.version_info < (3, 3),
-                     'Links are not supported under Windows before Python 3.3')
     def test_lexists(self):
         file_path = 'foo!bar!baz'
         self.filesystem.create_dir('foo!bar')
@@ -1095,8 +1075,6 @@ class FakePathModuleTest(TestCase):
         self.assert_raises_os_error(errno.ENOENT, self.path.getmtime,
                                     'it_dont_exist')
 
-    @unittest.skipIf(TestCase.is_windows and sys.version_info < (3, 3),
-                     'Links are not supported under Windows before Python 3.3')
     def test_islink(self):
         self.filesystem.create_dir('foo')
         self.filesystem.create_file('foo!regular_file')
@@ -1113,8 +1091,6 @@ class FakePathModuleTest(TestCase):
 
         self.assertFalse(self.path.islink('it_dont_exist'))
 
-    @unittest.skipIf(TestCase.is_windows and sys.version_info < (3, 3),
-                     'Links are not supported under Windows before Python 3.3')
     def test_is_link_case_sensitive(self):
         # Regression test for #306
         self.filesystem.is_case_sensitive = False
@@ -1140,8 +1116,6 @@ class FakePathModuleTest(TestCase):
         self.assertTrue(self.path.ismount('!mount'))
         self.assertTrue(self.path.ismount('!mount!'))
 
-    @unittest.skipIf(sys.version_info < (2, 7, 8),
-                     'UNC path support since Python 2.7.8')
     def test_ismount_with_unc_paths(self):
         self.filesystem.is_windows_fs = True
         self.assertTrue(self.path.ismount('!!a!'))
@@ -1159,46 +1133,14 @@ class FakePathModuleTest(TestCase):
         self.filesystem.is_windows_fs = True
         self.assertTrue(self.path.ismount('Z:!'))
 
-    @unittest.skipIf(sys.version_info >= (3, 0),
-                     'os.path.walk removed in Python 3')
-    def test_walk(self):
-        self.filesystem.create_file('!foo!bar!baz')
-        self.filesystem.create_file('!foo!bar!xyzzy!plugh')
-        visited_nodes = []
-
-        def RecordVisitedNodes(visited, dirname, fnames):
-            visited.extend(((dirname, fname) for fname in fnames))
-
-        self.path.walk('!foo', RecordVisitedNodes, visited_nodes)
-        expected = [('!foo', 'bar'),
-                    ('!foo!bar', 'baz'),
-                    ('!foo!bar', 'xyzzy'),
-                    ('!foo!bar!xyzzy', 'plugh')]
-        self.assertEqual(expected, sorted(visited_nodes))
-
-    @unittest.skipIf(sys.version_info >= (3, 0) or TestCase.is_windows,
-                     'os.path.walk deprecrated in Python 3, '
-                     'cannot be properly tested in win32')
-    def test_walk_from_nonexistent_top_does_not_throw(self):
-        visited_nodes = []
-
-        def RecordVisitedNodes(visited, dirname, fnames):
-            visited.extend(((dirname, fname) for fname in fnames))
-
-        self.path.walk('!foo', RecordVisitedNodes, visited_nodes)
-        self.assertEqual([], visited_nodes)
-
     def test_getattr_forward_to_real_os_path(self):
         """Forwards any non-faked calls to os.path."""
         self.assertTrue(hasattr(self.path, 'sep'),
                         'Get a faked os.path function')
         private_path_function = None
-        if (2, 7) <= sys.version_info < (3, 6):
+        if sys.version_info < (3, 6):
             if self.is_windows:
-                if sys.version_info >= (3, 0):
-                    private_path_function = '_get_bothseps'
-                else:
-                    private_path_function = '_abspath_split'
+                private_path_function = '_get_bothseps'
             else:
                 private_path_function = '_joinrealpath'
         if private_path_function:
@@ -1436,8 +1378,6 @@ class DriveLetterSupportTest(TestCase):
         self.assertEqual('c:!foo!bar',
                          self.filesystem.normpath('c:!!foo!!bar'))
 
-    @unittest.skipIf(sys.version_info < (2, 7, 8),
-                     'UNC path support since Python 2.7.8')
     def test_collapse_unc_path(self):
         self.assertEqual('!!foo!bar!baz',
                          self.filesystem.normpath('!!foo!bar!!baz!!'))
@@ -1516,8 +1456,6 @@ class DriveLetterSupportTest(TestCase):
         self.assertEqual((b'', b'!foo!bar'),
                          self.filesystem.splitdrive(b'!foo!bar'))
 
-    @unittest.skipIf(sys.version_info < (2, 7, 8),
-                     'UNC path support since Python 2.7.8')
     def test_split_drive_with_unc_path(self):
         self.assertEqual(('!!foo!bar', '!baz'),
                          self.filesystem.splitdrive('!!foo!bar!baz'))
@@ -1544,7 +1482,7 @@ class DiskSpaceTest(TestCase):
             with fake_open('!mount!file', 'w') as dest:
                 dest.write('a' * (total_size + 1))
 
-        self.assertRaises((OSError, IOError), create_too_large_file)
+        self.assertRaises(OSError, create_too_large_file)
 
         self.assertEqual(0, self.filesystem.get_disk_usage('!mount').used)
 
@@ -1599,7 +1537,7 @@ class DiskSpaceTest(TestCase):
 
         try:
             self.filesystem.create_file('!foo!bar', contents=b'a' * 100)
-        except IOError:
+        except OSError:
             self.fail('File with contents fitting into disk space '
                       'could not be written.')
 
@@ -1612,7 +1550,7 @@ class DiskSpaceTest(TestCase):
 
         initial_usage = self.filesystem.get_disk_usage()
 
-        self.assertRaises(IOError, create_large_file)
+        self.assertRaises(OSError, create_large_file)
 
         self.assertEqual(initial_usage, self.filesystem.get_disk_usage())
 
@@ -1621,7 +1559,7 @@ class DiskSpaceTest(TestCase):
 
         try:
             self.filesystem.create_file('!foo!bar', st_size=100)
-        except IOError:
+        except OSError:
             self.fail(
                 'File with size fitting into disk space could not be written.')
 
@@ -1634,7 +1572,7 @@ class DiskSpaceTest(TestCase):
         def create_large_file():
             self.filesystem.create_file('!foo!bar', st_size=101)
 
-        self.assertRaises(IOError, create_large_file)
+        self.assertRaises(OSError, create_large_file)
 
         self.assertEqual(initial_usage, self.filesystem.get_disk_usage())
 
@@ -1643,15 +1581,15 @@ class DiskSpaceTest(TestCase):
         try:
             file_object.set_large_file_size(100)
             file_object.set_contents(b'a' * 100)
-        except IOError:
+        except OSError:
             self.fail(
                 'Resizing file failed although disk space was sufficient.')
 
     def test_resize_file_with_size_too_large(self):
         file_object = self.filesystem.create_file('!foo!bar', st_size=50)
-        self.assert_raises_io_error(errno.ENOSPC,
+        self.assert_raises_os_error(errno.ENOSPC,
                                     file_object.set_large_file_size, 200)
-        self.assert_raises_io_error(errno.ENOSPC, file_object.set_contents,
+        self.assert_raises_os_error(errno.ENOSPC, file_object.set_contents,
                                     'a' * 150)
 
     def test_file_system_size_after_directory_rename(self):
@@ -1664,8 +1602,6 @@ class DiskSpaceTest(TestCase):
         self.os.rename('!foo!bar', '!foo!baz')
         self.assertEqual(20, self.filesystem.get_disk_usage().used)
 
-    @unittest.skipIf(TestCase.is_windows and sys.version_info < (3, 3),
-                     'Links are not supported under Windows before Python 3.3')
     def test_that_hard_link_does_not_change_used_size(self):
         file1_path = 'test_file1'
         file2_path = 'test_file2'
@@ -1685,10 +1621,10 @@ class DiskSpaceTest(TestCase):
         self.filesystem.add_mount_point('!mount_limited', total_size=50)
         self.filesystem.add_mount_point('!mount_unlimited')
 
-        self.assert_raises_io_error(errno.ENOSPC,
+        self.assert_raises_os_error(errno.ENOSPC,
                                     self.filesystem.create_file,
                                     '!mount_limited!foo', st_size=60)
-        self.assert_raises_io_error(errno.ENOSPC, self.filesystem.create_file,
+        self.assert_raises_os_error(errno.ENOSPC, self.filesystem.create_file,
                                     '!bar', st_size=110)
 
         try:
@@ -1696,7 +1632,7 @@ class DiskSpaceTest(TestCase):
             self.filesystem.create_file('!mount_limited!foo', st_size=40)
             self.filesystem.create_file('!mount_unlimited!foo',
                                         st_size=1000000)
-        except IOError:
+        except OSError:
             self.fail('File with contents fitting into '
                       'disk space could not be written.')
 
@@ -1716,7 +1652,7 @@ class DiskSpaceTest(TestCase):
 
     def test_set_larger_disk_size(self):
         self.filesystem.add_mount_point('!mount1', total_size=20)
-        self.assert_raises_io_error(errno.ENOSPC,
+        self.assert_raises_os_error(errno.ENOSPC,
                                     self.filesystem.create_file, '!mount1!foo',
                                     st_size=100)
         self.filesystem.set_disk_usage(total_size=200, path='!mount1')
@@ -1727,7 +1663,7 @@ class DiskSpaceTest(TestCase):
     def test_set_smaller_disk_size(self):
         self.filesystem.add_mount_point('!mount1', total_size=200)
         self.filesystem.create_file('!mount1!foo', st_size=100)
-        self.assert_raises_io_error(errno.ENOSPC,
+        self.assert_raises_os_error(errno.ENOSPC,
                                     self.filesystem.set_disk_usage,
                                     total_size=50, path='!mount1')
         self.filesystem.set_disk_usage(total_size=150, path='!mount1')
@@ -1756,8 +1692,6 @@ class DiskSpaceTest(TestCase):
         self.filesystem.set_disk_usage(total_size=1000, path='d:')
         self.assertEqual(self.filesystem.get_disk_usage('d:!foo').free, 800)
 
-    @unittest.skipIf(sys.version_info < (3, 0),
-                     'Tests byte contents in Python3')
     def test_copying_preserves_byte_contents(self):
         source_file = self.filesystem.create_file('foo', contents=b'somebytes')
         dest_file = self.filesystem.create_file('bar')
@@ -1817,8 +1751,6 @@ class MountPointTest(TestCase):
         self.assertEqual(6, self.filesystem.get_object('e:!foo').st_dev)
         self.assertEqual(6, self.filesystem.get_object('E:!Foo!Baz').st_dev)
 
-    @unittest.skipIf(sys.version_info < (2, 7, 8),
-                     'UNC path support since Python 2.7.8')
     def test_that_unc_paths_are_auto_mounted(self):
         self.filesystem.is_windows_fs = True
         self.filesystem.create_dir('!!foo!bar!baz')
@@ -1845,7 +1777,7 @@ class RealFileSystemAccessTest(TestCase):
 
     def test_add_non_existing_real_directory_raises(self):
         nonexisting_path = '/nonexisting'
-        self.assert_raises_io_error(errno.ENOENT,
+        self.assert_raises_os_error(errno.ENOENT,
                                     self.filesystem.add_real_directory,
                                     nonexisting_path)
         self.assertFalse(self.filesystem.exists(nonexisting_path))
@@ -1888,7 +1820,7 @@ class RealFileSystemAccessTest(TestCase):
             real_contents = f.read()
         self.assertEqual(fake_file.byte_contents, real_contents)
         if not is_root():
-            self.assert_raises_io_error(
+            self.assert_raises_os_error(
                 errno.EACCES, self.fake_open, real_file_path, 'w')
         else:
             with self.fake_open(real_file_path, 'w'):
@@ -1985,8 +1917,6 @@ class RealFileSystemAccessTest(TestCase):
         for link in symlinks:
             os.unlink(link[1])
 
-    @unittest.skipIf(TestCase.is_windows and sys.version_info < (3, 3),
-                     'Links are not supported under Windows before Python 3.3')
     def test_add_existing_real_directory_symlink(self):
         fake_open = fake_filesystem.FakeFileOpen(self.filesystem)
         real_directory = os.path.join(self.root_path, 'pyfakefs', 'tests')
@@ -2061,8 +1991,6 @@ class RealFileSystemAccessTest(TestCase):
             'good morning'
         )
 
-    @unittest.skipIf(TestCase.is_windows and sys.version_info < (3, 3),
-                     'Links are not supported under Windows before Python 3.3')
     def test_add_existing_real_directory_symlink_target_path(self):
         real_directory = os.path.join(self.root_path, 'pyfakefs', 'tests')
         symlinks = [
@@ -2089,8 +2017,6 @@ class RealFileSystemAccessTest(TestCase):
         self.assertTrue(self.filesystem.exists(
             '/path/fixtures/symlink_file_relative'))
 
-    @unittest.skipIf(TestCase.is_windows and sys.version_info < (3, 3),
-                     'Links are not supported under Windows before Python 3.3')
     def test_add_existing_real_directory_symlink_lazy_read(self):
         real_directory = os.path.join(self.root_path, 'pyfakefs', 'tests')
         symlinks = [
